.. include:: ../README.rst

User's Guide
============

This part of the documentation will show you how to get started in using
ESSM.

.. toctree::
   :maxdepth: 2

   installation
   usage

API Reference
=============

If you are looking for information on a specific function, class or method,
this part of the documentation is for you.

.. toctree::
   :maxdepth: 3

   api

Additional Notes
================

Notes on how to contribute, legal information and changes are here for the
interested.

.. toctree::
   :maxdepth: 1

   changes
   license
   authors

References
==========

.. bibliography:: refs.bib
   :cited:

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
